searchNodes=[{"doc":"Parameter is a library for dealing with complex datatypes by solving the following problems: Schema creation and validation Input data validation Deserialization Serialization Example Create a schema defmodule User do use Parameter.Schema alias Parameter.Validators param do field :first_name , :string , key : &quot;firstName&quot; , required : true field :last_name , :string , key : &quot;lastName&quot; field :email , :string , validator : &amp; Validators . email ( &amp;1 ) has_one :address , Address do field :city , :string , required : true field :street , :string field :number , :integer end end end Load (deserialize) the schema against external parameters: iex&gt; params = %{ &quot;firstName&quot; =&gt; &quot;John&quot; , &quot;lastName&quot; =&gt; &quot;Doe&quot; , &quot;email&quot; =&gt; &quot;john@email.com&quot; , &quot;address&quot; =&gt; %{ &quot;city&quot; =&gt; &quot;New York&quot; , &quot;street&quot; =&gt; &quot;York&quot; } } ...&gt; Parameter . load ( User , params ) { :ok , %{ first_name : &quot;John&quot; , last_name : &quot;Doe&quot; , email : &quot;john@email.com&quot; , main_address : %{ city : &quot;New York&quot; , street : &quot;York&quot; } } } or Dump (serialize) a populated schema to params: iex&gt; schema = %{ first_name : &quot;John&quot; , last_name : &quot;Doe&quot; , email : &quot;john@email.com&quot; , main_address : %{ city : &quot;New York&quot; , street : &quot;York&quot; } } ...&gt; Parameter . dump ( User , params ) { :ok , %{ &quot;firstName&quot; =&gt; &quot;John&quot; , &quot;lastName&quot; =&gt; &quot;Doe&quot; , &quot;email&quot; =&gt; &quot;john@email.com&quot; , &quot;address&quot; =&gt; %{ &quot;city&quot; =&gt; &quot;New York&quot; , &quot;street&quot; =&gt; &quot;York&quot; } } } Installation Add parameter to your list of dependencies in mix.exs : def deps do [ { :parameter , &quot;~&gt; 0.5&quot; } ] end add :parameter on .formatter.exs : import_deps : [ :ecto , :phoenix , ... , :parameter ] , Motivation Offer a similar Schema model from Ecto library to deal with complex data schemas. The main use case is to parse response from external apis. Parameter provides a well structured schema model which tries it's best to parse the external data. Schema The first step for building a schema for your data is to create a schema definition to model the external data. This can be achieved by using the Parameter.Schema macro. The example below mimics an User model that have one main_address and a list of phones . defmodule User do use Parameter.Schema param do field :first_name , :string , key : &quot;firstName&quot; , required : true field :last_name , :string , key : &quot;lastName&quot; , required : true , default : &quot;&quot; has_one :main_address , Address , key : &quot;mainAddress&quot; , required : true has_many :phones , Phone end end defmodule Address do use Parameter.Schema param do field :city , :string , required : true field :street , :string field :number , :integer end end defmodule Phone do use Parameter.Schema param do field :country , :string field :number , :integer end end Parameter offers other ways for creating a schema such as nesting the has_one and has_many fields. This require module name as the second parameter using do at the end: defmodule User do use Parameter.Schema param do field :first_name , :string , key : &quot;firstName&quot; , required : true field :last_name , :string , key : &quot;lastName&quot; , required : true , default : &quot;&quot; has_one :main_address , Address , key : &quot;mainAddress&quot; , required : true do field :city , :string , required : true field :street , :string field :number , :integer end has_many :phones , Phone do field :country , :string field :number , :integer end end end Another possibility is avoiding creating files for a schema at all. This can be done by importing Parameter.Schema and using the param/2 macro. This is useful for adding params in Phoenix controllers. For example: defmodule MyProjectWeb.UserController do use MyProjectWeb , :controller import Parameter.Schema alias MyProject.Users param UserParams do field :first_name , :string , required : true field :last_name , :string , required : true end def create ( conn , params ) do with { :ok , user_params } &lt;- Parameter . load ( __MODULE__ . UserParams , params ) , { :ok , user } &lt;- Users . create_user ( user_params ) do render ( conn , &quot;user.json&quot; , %{ user : user } ) end end end It's recommended to use this approach when the schema will only be used in a single module. Types Each field needs to define the type that will be parsed and the options (if any). The available types are: :string :atom :any :integer :float :boolean :map :array :date :time :datetime :naive_datetime :decimal * enum ** module * * For decimal type add the decimal library into your project. ** Check the Parameter.Enum for more information on how to use enums. *** Any module that implements the Parameter.Parametrizable behaviour is eligible to be a field in the schema definition. The options available for the field definition are: key : This is the key on the external source that will be converted to the param definition. As an example, if you receive data from an external source that uses a camel case for mapping first_name , this flag should be key: &quot;firstName&quot; . If this parameter is not set it will default to the field name. default : default value of the field. required : defines if the field needs to be present when parsing the input. After the definition, the schema can be validated and parsed against external parameters using the Parameter.load/3 function. Data Deserialization This is a common requirement when receiving data from an external source that needs validation and deserialization of data to an Elixir definition. This can be achieved using Parameter.load/2 or Parameter.load/3 functions: iex&gt; params = %{ &quot;mainAddress&quot; =&gt; %{ &quot;city&quot; =&gt; &quot;New York&quot; } , &quot;phones&quot; =&gt; [ %{ &quot;country&quot; =&gt; &quot;USA&quot; , &quot;number&quot; =&gt; &quot;123456789&quot; } ] , &quot;firstName&quot; =&gt; &quot;John&quot; , &quot;lastName&quot; =&gt; &quot;Doe&quot; } ...&gt; Parameter . load ( User , params ) { :ok , %{ first_name : &quot;John&quot; , last_name : &quot;Doe&quot; , main_address : %{ city : &quot;New York&quot; } , phones : [ %{ country : &quot;USA&quot; , number : 123456789 } ] } } Return struct fields ...&gt; Parameter . load ( User , params , struct : true ) { :ok , % User { first_name : &quot;John&quot; , last_name : &quot;Doe&quot; , main_address : % Address { city : &quot;New York&quot; , number : nil , street : nil } , phones : [ % Phone { country : &quot;USA&quot; , number : 123456789 } ] } } Invalid data should return validation errors: iex&gt; params = %{ &quot;mainAddress&quot; =&gt; %{ &quot;city&quot; =&gt; &quot;New York&quot; , &quot;number&quot; =&gt; &quot;123AB&quot; } , &quot;phones&quot; =&gt; [ %{ &quot;country&quot; =&gt; &quot;USA&quot; , &quot;number&quot; =&gt; &quot;123AB&quot; } , %{ &quot;country&quot; =&gt; &quot;Brazil&quot; , &quot;number&quot; =&gt; &quot;Not number&quot; } ] , &quot;lastName&quot; =&gt; &quot;Doe&quot; } ...&gt; Parameter . load ( User , params ) { :error , %{ first_name : &quot;is required&quot; , main_address : %{ number : &quot;invalid integer type&quot; } , phones : [ &quot;0&quot; : %{ number : &quot;invalid integer type&quot; } , &quot;1&quot; : %{ number : &quot;invalid integer type&quot; } ] } } The options for Parameter.load/3 are: struct : If true returns the response with elixir structs. false uses plain maps. unknown : Defines the behaviour when dealing with unknown fields on input data. The options are :ignore and :error Data Serialization This is a common requirement when dealing with internal data that needs to be send to an external source. This can be achieved using Parameter.dump/2 function: iex&gt; loaded_params = %{ phones : [ %{ country : &quot;USA&quot; , number : 123456789 } ] , first_name : &quot;John&quot; , last_name : &quot;Doe&quot; , main_address : %{ city : &quot;New York&quot; } } ...&gt; Parameter . dump ( User , loaded_params ) { :ok , %{ &quot;firstName&quot; =&gt; &quot;John&quot; , &quot;lastName&quot; =&gt; &quot;Doe&quot; , &quot;mainAddress&quot; =&gt; %{ &quot;city&quot; =&gt; &quot;New York&quot; } , &quot;phones&quot; =&gt; [ %{ &quot;country&quot; =&gt; &quot;USA&quot; , &quot;number&quot; =&gt; 123456789 } ] } } Custom Types For implementing custom types create a module that implements the Parameter.Parametrizable behaviour. Check the following example on how Integer parameter was implemented: defmodule IntegerCustomType do @moduledoc &quot;&quot;&quot; Integer parameter type &quot;&quot;&quot; use Parameter.Parametrizable @impl true # `load/1` should handle deserialization of a value def load ( value ) when is_integer ( value ) do { :ok , value } end def load ( value ) when is_binary ( value ) do case Integer . parse ( value ) do { integer , &quot;&quot; } -&gt; { :ok , integer } _error -&gt; error_tuple ( ) end end def load ( _value ) do { :error , &quot;invalid integer type&quot; } end @impl true # `dump/1` should handle serialization of a value def dump ( value ) do case validate ( value ) do :ok -&gt; { :ok , value } error -&gt; error end end @impl true # `validate/1` checks the schema during compile time. It verifies the default value if it&#39;s passed to the schema validating its type def validate ( value ) when is_integer ( value ) do :ok end def validate ( _value ) do { :error , &quot;invalid integer type&quot; } end end Add the custom module on the schema definition: defmodule User do use Parameter.Schema param do field :age , IntegerCustomType , required : true end end Unknown fields Loading will ignore fields that does not have a matching key in the schema. This behaviour can be changed with the following options: :ignore (default): ignore unknown fields :error : return an error with the unknown fields Using the same user schema, adding unknow field option to error should return an error: iex&gt; params = %{ &quot;user_token&quot; =&gt; &quot;3hgj81312312&quot; } ...&gt; Parameter . load ( User , params , unknown : :error ) { :error , %{ &quot;user_token&quot; =&gt; &quot;unknown field&quot; } } Validation Parameter comes with a set of validators to validate the schema after loading. The implemented validators are described in the module Parameter.Validators . defmodule User do use Parameter.Schema alias Parameter.Validators param do field :email , :string , validator : &amp; Validators . email / 1 field :age , :integer , validator : { &amp; Validators . length / 2 , min : 18 , max : 72 } field :code , :string , validator : { &amp; Validators . regex / 2 , regex : ~r/code/ } field :user_code , :string , validator : { &amp; __MODULE__ . is_equal / 2 , to : &quot;0000&quot; } field :permission , :atom , required : true , validator : { &amp; Validators . one_of / 2 , options : [ :admin , :normal ] } end # To add a custom validator create a function with arity 1 or 2. # The first parameter is always the field value and the second (and optional) # parameter is a `Keyword` list that will be used to pass values on the schema # The function must always return `:ok` or `{:error, reason}` def is_equal ( value , to : to_value ) do if value == to_value do :ok else { :error , &quot;not equal&quot; } end end end Sending wrong parameters: iex&gt; params = %{ &quot;email&quot; =&gt; &quot;not email&quot; , &quot;age&quot; =&gt; &quot;12&quot; , &quot;code&quot; =&gt; &quot;asdf&quot; , &quot;user_code&quot; =&gt; &quot;12345&quot; , &quot;permission&quot; =&gt; &quot;super_admin&quot; } ...&gt; Parameter . load ( User , params ) { :error , %{ age : &quot;is invalid&quot; , code : &quot;is invalid&quot; , email : &quot;is invalid&quot; , permission : &quot;is invalid&quot; , user_code : &quot;not equal&quot; } } Correct input should result in the schema loaded correctly: iex&gt; params = %{ &quot;email&quot; =&gt; &quot;john@email.com&quot; , &quot;age&quot; =&gt; &quot;22&quot; , &quot;code&quot; =&gt; &quot;code:13234&quot; , &quot;permission&quot; =&gt; &quot;admin&quot; , &quot;user_code&quot; =&gt; &quot;0000&quot; } ...&gt; Parameter . load ( User , params ) { :ok , %{ age : 22 , code : &quot;code:13234&quot; , email : &quot;john@email.com&quot; , permission : :admin , user_code : &quot;0000&quot; } } Excluding fields on serialization and deserialization Pass the exclude key on the third argument of Parameter.load/3 or Parameter.dump/3 with a list of the fields to be excluded. Those fields won't be considered when serializing/deserializing the parameters. iex&gt; params = %{ &quot;firstName&quot; =&gt; &quot;John&quot; , &quot;lastName&quot; =&gt; &quot;Doe&quot; , &quot;email&quot; =&gt; &quot;john@email.com&quot; , &quot;address&quot; =&gt; %{ &quot;city&quot; =&gt; &quot;New York&quot; , &quot;street&quot; =&gt; &quot;York&quot; } } ...&gt; Parameter . load ( User , params , exclude : [ :first_name ] ) { :ok , %{ last_name : &quot;Doe&quot; , email : &quot;john@email.com&quot; , main_address : %{ city : &quot;New York&quot; , street : &quot;York&quot; } } } ...&gt; Parameter . load ( User , params , exclude : [ :first_name , { :address , [ :street ] } ] ) { :ok , %{ last_name : &quot;Doe&quot; , email : &quot;john@email.com&quot; , main_address : %{ city : &quot;New York&quot; } } }","ref":"Parameter.html","title":"Parameter","type":"module"},{"doc":"","ref":"Parameter.html#dump/3","title":"Parameter.dump/3","type":"function"},{"doc":"","ref":"Parameter.html#load/3","title":"Parameter.load/3","type":"function"},{"doc":"Enum type represents a group of constants that have a value with an associated key. Example defmodule MyApp.UserParam do use Parameter.Schema enum Status do value &quot;userOnline&quot; , as : :user_online value &quot;userOffline&quot; , as : :user_offline end param do field :first_name , :string , key : &quot;firstName&quot; field :status , MyApp.UserParam.Status end end The Status enum should automatically translate the userOnline and userOffline values when loading to the respective atom values. iex&gt; Parameter . load ( MyApp.UserParam , %{ &quot;firstName&quot; =&gt; &quot;John&quot; , &quot;status&quot; =&gt; &quot;userOnline&quot; } ) { :ok , %{ first_name : &quot;John&quot; , status : :user_online } } ...&gt; # It also uses the key for dumping: ...&gt; Parameter . dump ( MyApp.UserParam , %{ first_name : &quot;John&quot; , status : :user_online } ) { :ok , %{ &quot;firstName&quot; =&gt; &quot;John&quot; , &quot;status&quot; =&gt; &quot;userOnline&quot; } } Enum also supports a shorter version if the key and value are already the same: defmodule MyApp.UserParam do ... enum Status , values : [ :user_online , :user_offline ] ... end iex&gt; Parameter . load ( MyApp.UserParam , %{ &quot;firstName&quot; =&gt; &quot;John&quot; , &quot;status&quot; =&gt; &quot;user_online&quot; } ) { :ok , %{ first_name : &quot;John&quot; , status : :user_online } } It's also possible to create enums in different modules by using the enum/1 macro: defmodule MyApp.Status do import Parameter.Enum enum do value &quot;userOnline&quot; , as : :user_online value &quot;userOffline&quot; , as : :user_offline end end defmodule MyApp.UserParam do use Parameter.Schema alias MyApp.Status param do field :first_name , :string , key : &quot;firstName&quot; field :status , Status end end And the short version: enum values : [ :user_online , :user_offline ]","ref":"Parameter.Enum.html","title":"Parameter.Enum","type":"module"},{"doc":"","ref":"Parameter.Enum.html#enum/1","title":"Parameter.Enum.enum/1","type":"macro"},{"doc":"","ref":"Parameter.Enum.html#enum/2","title":"Parameter.Enum.enum/2","type":"macro"},{"doc":"","ref":"Parameter.Enum.html#value/2","title":"Parameter.Enum.value/2","type":"macro"},{"doc":"Logic for dealing with excluded fields list.","ref":"Parameter.ExcludeFields.html","title":"Parameter.ExcludeFields","type":"module"},{"doc":"","ref":"Parameter.ExcludeFields.html#field_to_exclude/2","title":"Parameter.ExcludeFields.field_to_exclude/2","type":"function"},{"doc":"This module define the structure of a Field inside a Parameter Schema.","ref":"Parameter.Field.html","title":"Parameter.Field","type":"module"},{"doc":"","ref":"Parameter.Field.html#new/1","title":"Parameter.Field.new/1","type":"function"},{"doc":"","ref":"Parameter.Field.html#new!/1","title":"Parameter.Field.new!/1","type":"function"},{"doc":"","ref":"Parameter.Field.html#t:t/0","title":"Parameter.Field.t/0","type":"type"},{"doc":"Custom types per fields to be implemented using Parameter.Parametrizable module. When the basic types are not enough for loading, validating and dumping data this module can be used to provide custom types. Example To create a parameterized type, create a module as shown below: defmodule MyApp.CustomType do use Parameter.Parametrizable @impl true def load ( value ) do { :ok , value } end @impl true def validate ( _value ) do :ok end @impl true def dump ( value ) do { :ok , value } end end Then use the new custom type on a param schema: param MyApp.CustomParam do field :custom_field , MyApp.CustomType , key : &quot;customField&quot; end In general is not necessary to implement dump function since using the macro use Parameter.Parametrizable will already use the validate function to dump the value as a default implementation.","ref":"Parameter.Parametrizable.html","title":"Parameter.Parametrizable","type":"behaviour"},{"doc":"","ref":"Parameter.Parametrizable.html#c:dump/1","title":"Parameter.Parametrizable.dump/1","type":"callback"},{"doc":"","ref":"Parameter.Parametrizable.html#c:load/1","title":"Parameter.Parametrizable.load/1","type":"callback"},{"doc":"","ref":"Parameter.Parametrizable.html#c:validate/1","title":"Parameter.Parametrizable.validate/1","type":"callback"},{"doc":"Compile schema options","ref":"Parameter.Schema.Compiler.html","title":"Parameter.Schema.Compiler","type":"module"},{"doc":"","ref":"Parameter.Schema.Compiler.html#fetch_nested_opts!/1","title":"Parameter.Schema.Compiler.fetch_nested_opts!/1","type":"function"},{"doc":"Type behavour for implementing new types for parameters.","ref":"Parameter.Types.html","title":"Parameter.Types","type":"module"},{"doc":"","ref":"Parameter.Types.html#base_types/0","title":"Parameter.Types.base_types/0","type":"function"},{"doc":"","ref":"Parameter.Types.html#composite_types/0","title":"Parameter.Types.composite_types/0","type":"function"},{"doc":"","ref":"Parameter.Types.html#dump/2","title":"Parameter.Types.dump/2","type":"function"},{"doc":"","ref":"Parameter.Types.html#load/2","title":"Parameter.Types.load/2","type":"function"},{"doc":"","ref":"Parameter.Types.html#validate/2","title":"Parameter.Types.validate/2","type":"function"},{"doc":"","ref":"Parameter.Types.html#validate!/2","title":"Parameter.Types.validate!/2","type":"function"},{"doc":"","ref":"Parameter.Types.html#t:base_types/0","title":"Parameter.Types.base_types/0","type":"type"},{"doc":"","ref":"Parameter.Types.html#t:composite_types/0","title":"Parameter.Types.composite_types/0","type":"type"},{"doc":"","ref":"Parameter.Types.html#t:t/0","title":"Parameter.Types.t/0","type":"type"},{"doc":"Any parameter type. It will accept any input value without validations. The same value loaded will be the same dumped.","ref":"Parameter.Types.Any.html","title":"Parameter.Types.Any","type":"module"},{"doc":"Atom parameter type","ref":"Parameter.Types.Atom.html","title":"Parameter.Types.Atom","type":"module"},{"doc":"Boolean parameter type","ref":"Parameter.Types.Boolean.html","title":"Parameter.Types.Boolean","type":"module"},{"doc":"Date parameter type","ref":"Parameter.Types.Date.html","title":"Parameter.Types.Date","type":"module"},{"doc":"DateTime parameter type","ref":"Parameter.Types.DateTime.html","title":"Parameter.Types.DateTime","type":"module"},{"doc":"Decimal parameter type. Include the Decimal library on your application to use this type: def deps do [ { :parameter , &quot;~&gt; ...&quot; } , { :decimal , &quot;~&gt; 2.0&quot; } ] end","ref":"Parameter.Types.Decimal.html","title":"Parameter.Types.Decimal","type":"module"},{"doc":"Float parameter type","ref":"Parameter.Types.Float.html","title":"Parameter.Types.Float","type":"module"},{"doc":"Integer parameter type","ref":"Parameter.Types.Integer.html","title":"Parameter.Types.Integer","type":"module"},{"doc":"List parameter type","ref":"Parameter.Types.List.html","title":"Parameter.Types.List","type":"module"},{"doc":"Map parameter type","ref":"Parameter.Types.Map.html","title":"Parameter.Types.Map","type":"module"},{"doc":"NaiveDateTime parameter type","ref":"Parameter.Types.NaiveDateTime.html","title":"Parameter.Types.NaiveDateTime","type":"module"},{"doc":"String parameter type","ref":"Parameter.Types.String.html","title":"Parameter.Types.String","type":"module"},{"doc":"Time parameter type","ref":"Parameter.Types.Time.html","title":"Parameter.Types.Time","type":"module"},{"doc":"Common validators to use with the schema Example param User do field :email , :string , validator : &amp; Validators . email ( &amp;1 ) end iex&gt; Parameter . load ( User , %{ &quot;email&quot; =&gt; &quot;not an email&quot; } ) { :error , %{ email : &quot;is invalid&quot; } }","ref":"Parameter.Validators.html","title":"Parameter.Validators","type":"module"},{"doc":"Validates email address param User do field :email , :string , validator : &amp; Validators . email ( &amp;1 ) end iex&gt; Parameter . load ( User , %{ &quot;email&quot; =&gt; &quot;not an email&quot; } ) { :error , %{ email : &quot;is invalid&quot; } } iex&gt; Parameter . load ( User , %{ &quot;email&quot; =&gt; &quot;john@gmail.com&quot; } ) { :ok , %{ email : &quot;john@gmail.com&quot; } }","ref":"Parameter.Validators.html#email/1","title":"Parameter.Validators.email/1","type":"function"},{"doc":"Validates if value is equal to another param User do field :permission , :string , validator : { &amp; Validators . equal / 2 , to : &quot;admin&quot; } end iex&gt; Parameter . load ( User , %{ &quot;permission&quot; =&gt; &quot;super_admin&quot; } ) { :error , %{ permission : &quot;is invalid&quot; } } iex&gt; Parameter . load ( User , %{ &quot;permission&quot; =&gt; &quot;admin&quot; } ) { :ok , %{ permission : &quot;admin&quot; } }","ref":"Parameter.Validators.html#equal/2","title":"Parameter.Validators.equal/2","type":"function"},{"doc":"Validates if a value is between a min and max param User do field :age , :integer , validator : { &amp; Validators . length / 2 , min : 18 , max : 50 } end iex&gt; Parameter . load ( User , %{ &quot;age&quot; =&gt; 12 } ) { :error , %{ age : &quot;is invalid&quot; } } iex&gt; Parameter . load ( User , %{ &quot;age&quot; =&gt; 30 } ) { :ok , %{ age : 30 } }","ref":"Parameter.Validators.html#length/2","title":"Parameter.Validators.length/2","type":"function"},{"doc":"Validates if a value is not a member param User do field :permission , :atom , validator : { &amp; Validators . none_of / 2 , options : [ :admin , :super_admin ] } end iex&gt; Parameter . load ( User , %{ &quot;permission&quot; =&gt; &quot;super_admin&quot; } ) { :error , %{ permission : &quot;is invalid&quot; } } iex&gt; Parameter . load ( User , %{ &quot;permission&quot; =&gt; &quot;normal_user&quot; } ) { :ok , %{ permission : :normal_user } }","ref":"Parameter.Validators.html#none_of/2","title":"Parameter.Validators.none_of/2","type":"function"},{"doc":"Validates if a value is a member of the list param User do field :permission , :atom , validator : { &amp; Validators . one_of / 2 , options : [ :admin , :super_admin ] } end iex&gt; Parameter . load ( User , %{ &quot;permission&quot; =&gt; &quot;normal_user&quot; } ) { :error , %{ permission : &quot;is invalid&quot; } } iex&gt; Parameter . load ( User , %{ &quot;permission&quot; =&gt; &quot;super_admin&quot; } ) { :ok , %{ permission : :super_admin } }","ref":"Parameter.Validators.html#one_of/2","title":"Parameter.Validators.one_of/2","type":"function"},{"doc":"Validates if a value matches a regex expression param User do field :code , :string , validator : { &amp; Validators . regex / 2 , regex : ~r/code/ } end iex&gt; Parameter . load ( User , %{ &quot;code&quot; =&gt; &quot;12345&quot; } ) { :error , %{ code : &quot;is invalid&quot; } } iex&gt; Parameter . load ( User , %{ &quot;code&quot; =&gt; &quot;code:12345&quot; } ) { :ok , %{ code : &quot;code:12345&quot; } }","ref":"Parameter.Validators.html#regex/2","title":"Parameter.Validators.regex/2","type":"function"},{"doc":"","ref":"Parameter.Validators.html#t:resp/0","title":"Parameter.Validators.resp/0","type":"type"}]